<?php
/*
Plugin Name: Tee-Time
Plugin URI: #
Description: Golf Tee-time booking solution!
Text Domain: teetime
Version: 1.0.0
Author: Sudeepa Das
Author URI: #
*/

// Include custom functions file from the include folder
include_once(plugin_dir_path(__FILE__) . 'includes/shortcode.php');

// Hook to register custom post type and taxonomy
add_action('init', 'teetime_register_golf_club_post_type');

function teetime_register_golf_club_post_type() {
    $labels = array(
        'name' => __('Golf Clubs', 'teetime'),
        'singular_name' => __('Golf Club', 'teetime'),
        'menu_name' => __('Golf Clubs', 'teetime'),
        'name_admin_bar' => __('Golf Club', 'teetime'),
        'add_new' => __('Add New', 'teetime'),
        'add_new_item' => __('Add New Golf Club', 'teetime'),
        'new_item' => __('New Golf Club', 'teetime'),
        'edit_item' => __('Edit Golf Club', 'teetime'),
        'view_item' => __('View Golf Club', 'teetime'),
        'all_items' => __('All Golf Clubs', 'teetime'),
        'search_items' => __('Search Golf Clubs', 'teetime'),
        'not_found' => __('No Golf Clubs found', 'teetime'),
    );

    $args = array(
        'labels' => $labels,
        'public' => true,
        'has_archive' => true,
        'supports' => array('title', 'editor', 'thumbnail', 'custom-fields'), // Removed 'price' from meta fields
        'menu_icon' => 'dashicons-calendar-alt',
        'show_in_rest' => true,
        'rewrite' => array('slug' => 'golf-clubs'),
    );

    register_post_type('golf-club', $args);

    // Register custom taxonomy for category
    teetime_register_golf_club_taxonomy();
}

// Function to register taxonomy for golf clubs
function teetime_register_golf_club_taxonomy() {
    $labels = array(
        'name' => __('Categories', 'teetime'),
        'singular_name' => __('Category', 'teetime'),
        'search_items' => __('Search Categories', 'teetime'),
        'all_items' => __('All Categories', 'teetime'),
        'parent_item' => __('Parent Category', 'teetime'),
        'parent_item_colon' => __('Parent Category:', 'teetime'),
        'edit_item' => __('Edit Category', 'teetime'),
        'update_item' => __('Update Category', 'teetime'),
        'add_new_item' => __('Add New Category', 'teetime'),
        'new_item_name' => __('New Category Name', 'teetime'),
        'menu_name' => __('Categories', 'teetime'),
    );

    $args = array(
        'hierarchical' => true,  // Like categories
        'labels' => $labels,
        'show_ui' => true,
        'show_admin_column' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'golf-club-category'),
        'show_in_rest' => true,
    );

    register_taxonomy('golf_club_category', array('golf-club'), $args);
}

// Add meta boxes for additional fields (without price)
add_action('add_meta_boxes', 'teetime_add_custom_meta_boxes');

function teetime_add_custom_meta_boxes() {
    add_meta_box(
        'golf_club_details',
        __('Golf Club Details', 'teetime'),
        'teetime_golf_club_meta_box_callback',
        'golf-club',
        'normal',
        'default'
    );
}

function teetime_golf_club_meta_box_callback($post) {
    // Add nonce for security
    wp_nonce_field('teetime_save_golf_club_data', 'teetime_golf_club_meta_box_nonce');

    $start_time = get_post_meta($post->ID, '_golf_club_start_time', true);
    $end_time = get_post_meta($post->ID, '_golf_club_end_time', true);
    $duration = get_post_meta($post->ID, '_golf_club_duration', true);
    $capacity = get_post_meta($post->ID, '_golf_club_capacity', true);

    ?>
    <p>
        <label for="golf_club_start_time"><?php _e('Start Time:', 'teetime'); ?></label>
        <input type="time" id="golf_club_start_time" name="golf_club_start_time" value="<?php echo esc_attr($start_time); ?>" class="widefat" />
    </p>
    <p>
        <label for="golf_club_end_time"><?php _e('End Time:', 'teetime'); ?></label>
        <input type="time" id="golf_club_end_time" name="golf_club_end_time" value="<?php echo esc_attr($end_time); ?>" class="widefat" />
    </p>
    <p>
        <label for="golf_club_duration"><?php _e('Duration (Minutes):', 'teetime'); ?></label>
        <input type="number" id="golf_club_duration" name="golf_club_duration" value="<?php echo esc_attr($duration); ?>" class="widefat" />
    </p>
    <p>
        <label for="golf_club_capacity"><?php _e('Capacity Per Slot:', 'teetime'); ?></label>
        <input type="number" id="golf_club_capacity" name="golf_club_capacity" value="<?php echo esc_attr($capacity); ?>" class="widefat" />
    </p>
    <?php
}

// Save meta box data (without price field)
add_action('save_post', 'teetime_save_golf_club_data');

function teetime_save_golf_club_data($post_id) {
    if (!isset($_POST['teetime_golf_club_meta_box_nonce']) || !wp_verify_nonce($_POST['teetime_golf_club_meta_box_nonce'], 'teetime_save_golf_club_data')) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    if (isset($_POST['post_type']) && 'golf-club' === $_POST['post_type']) {
        if (!current_user_can('edit_post', $post_id)) {
            return;
        }
    }

    $fields = [
        'golf_club_start_time' => '_golf_club_start_time',
        'golf_club_end_time' => '_golf_club_end_time',
        'golf_club_duration' => '_golf_club_duration',
        'golf_club_capacity' => '_golf_club_capacity',
    ];

    foreach ($fields as $field_name => $meta_key) {
        if (isset($_POST[$field_name])) {
            update_post_meta($post_id, $meta_key, sanitize_text_field($_POST[$field_name]));
        }
    }
}

// Enqueue jQuery and SweetAlert scripts
function enqueue_jquery() {
    wp_enqueue_script('jquery');
}
add_action('wp_enqueue_scripts', 'enqueue_jquery');

function enqueue_sweetalert() {
    wp_enqueue_script('sweetalert-js', 'https://cdn.jsdelivr.net/npm/sweetalert2@11', array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'enqueue_sweetalert');
